@@ -1,9 +1,9 @@
 package BorderStyle;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-23'; # DATE
+our $DATE = '2021-01-31'; # DATE
 our $DIST = 'BorderStyle'; # DIST
-our $VERSION = '2.0.4'; # VERSION
+our $VERSION = '2.0.5'; # VERSION
 
 1;
 # ABSTRACT: Border styles
@@ -24,7 +24,7 @@ BorderStyle - Border styles
 
 =head1 VERSION
 
-This document describes version 2.0.4 of BorderStyle (from Perl distribution BorderStyle), released on 2021-01-23.
+This document describes version 2.0.5 of BorderStyle (from Perl distribution BorderStyle), released on 2021-01-31.
 
 =head1 DESCRIPTION
 
@@ -132,12 +132,14 @@ An array. Required. Format for the characters in C<chars>:
 
  [                           # y
  #x 0  1  2  3  4  5  6  7
-   [A, B, C, D,              # 0 Top border characters
+   [A, B, C, D],             # 0 Top border characters (if drawing header row)
    [E, F, G],                # 1 Vertical separators for header row
    [H, I, J, K, a, b],       # 2 Separator between header row and first data row
    [L, M, N],                # 3 Vertical separators for data row
    [O, P, Q, R, e, f, g, h], # 4 Separator between data rows
    [S, T, U, V],             # 5 Bottom border characters
+
+   [Ȧ, Ḃ, Ċ, Ḋ],             # 6 Top border characters (if not drawing header row)
  ]
 
 When drawing border, below is how the border characters will be used:
